# COVIDcast API client

Provides Python access to the [COVIDcast
API](https://cmu-delphi.github.io/delphi-epidata/api/covidcast.html) published
by the [Delphi group](https://delphi.cmu.edu/) at [Carnegie Mellon
University](https://www.cmu.edu). This API provides daily access to a range of
COVID-related signals Delphi collects from a variety of sources, including
cases, deaths, symptom surveys, healthcare data, and other information. This
package also provides convenient tools for mapping and analyzing the API's data.

For installation instructions, documentation, and examples, consult the [package
documentation](https://cmu-delphi.github.io/covidcast/covidcast-py/html/).
